import typing

import android.app
import android.bluetooth
import android.bluetooth.le
import android.content
import android.net
import android.net.wifi
import android.os
import java
import java.chaquopy
import java.io
import java.lang
import java.nio
import java.util
import java.util.concurrent
import java.util.regex

class AssociatedDevice(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AssociatedDevice]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBleDevice(self) -> android.bluetooth.le.ScanResult | None: ...
    def getBluetoothDevice(self) -> android.bluetooth.BluetoothDevice | None: ...
    def getWifiDevice(self) -> android.net.wifi.ScanResult | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AssociationInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AssociationInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAssociatedDevice(self) -> AssociatedDevice | None: ...
    def getDeviceId(self) -> DeviceId: ...
    def getDeviceMacAddress(self) -> android.net.MacAddress | None: ...
    def getDeviceProfile(self) -> str | None: ...
    def getDisplayName(self) -> java.lang.CharSequence | None: ...
    def getId(self) -> int: ...
    def getSystemDataSyncFlags(self) -> int: ...
    def hashCode(self) -> int: ...
    def isSelfManaged(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AssociationRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AssociationRequest]] = ...
    DEVICE_PROFILE_APP_STREAMING: typing.ClassVar[str] = ...
    DEVICE_PROFILE_AUTOMOTIVE_PROJECTION: typing.ClassVar[str] = ...
    DEVICE_PROFILE_COMPUTER: typing.ClassVar[str] = ...
    DEVICE_PROFILE_GLASSES: typing.ClassVar[str] = ...
    DEVICE_PROFILE_NEARBY_DEVICE_STREAMING: typing.ClassVar[str] = ...
    DEVICE_PROFILE_WATCH: typing.ClassVar[str] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDeviceProfile(self) -> str | None: ...
    def getDisplayName(self) -> java.lang.CharSequence | None: ...
    def hashCode(self) -> int: ...
    def isForceConfirmation(self) -> bool: ...
    def isSelfManaged(self) -> bool: ...
    def isSingleDevice(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addDeviceFilter(self, deviceFilter: DeviceFilter[java.lang.Object], /) -> AssociationRequest.Builder: ...
        def build(self) -> AssociationRequest: ...
        def setDeviceProfile(self, deviceProfile: str | java.lang.String, /) -> AssociationRequest.Builder: ...
        def setDisplayName(self, displayName: java.lang.CharSequence, /) -> AssociationRequest.Builder: ...
        def setForceConfirmation(self, forceConfirmation: bool | java.jboolean | java.lang.Boolean, /) -> AssociationRequest.Builder: ...
        def setSelfManaged(self, selfManaged: bool | java.jboolean | java.lang.Boolean, /) -> AssociationRequest.Builder: ...
        def setSingleDevice(self, singleDevice: bool | java.jboolean | java.lang.Boolean, /) -> AssociationRequest.Builder: ...

class BluetoothDeviceFilter(DeviceFilter[android.bluetooth.BluetoothDevice]):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothDeviceFilter]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addServiceUuid(self, serviceUuid: android.os.ParcelUuid, serviceUuidMask: android.os.ParcelUuid, /) -> BluetoothDeviceFilter.Builder: ...
        def build(self) -> BluetoothDeviceFilter: ...
        def setAddress(self, address: str | java.lang.String, /) -> BluetoothDeviceFilter.Builder: ...
        def setNamePattern(self, regex: java.util.regex.Pattern, /) -> BluetoothDeviceFilter.Builder: ...

class BluetoothLeDeviceFilter(DeviceFilter[android.bluetooth.le.ScanResult]):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothLeDeviceFilter]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def getRenamePrefixLengthLimit() -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> BluetoothLeDeviceFilter: ...
        def setNamePattern(self, regex: java.util.regex.Pattern, /) -> BluetoothLeDeviceFilter.Builder: ...
        def setRawDataFilter(self, rawDataFilter: java.chaquopy.JavaArrayJByte, rawDataFilterMask: java.chaquopy.JavaArrayJByte, /) -> BluetoothLeDeviceFilter.Builder: ...
        def setRenameFromBytes(self, prefix: str | java.lang.String, suffix: str | java.lang.String, bytesFrom: int | java.jint | java.lang.Integer, bytesLength: int | java.jint | java.lang.Integer, byteOrder: java.nio.ByteOrder, /) -> BluetoothLeDeviceFilter.Builder: ...
        def setRenameFromName(self, prefix: str | java.lang.String, suffix: str | java.lang.String, nameFrom: int | java.jint | java.lang.Integer, nameLength: int | java.jint | java.lang.Integer, /) -> BluetoothLeDeviceFilter.Builder: ...
        def setScanFilter(self, scanFilter: android.bluetooth.le.ScanFilter, /) -> BluetoothLeDeviceFilter.Builder: ...

class CompanionDeviceManager(java.lang.Object):
    EXTRA_ASSOCIATION: typing.ClassVar[str] = ...
    EXTRA_DEVICE: typing.ClassVar[str] = ...
    FLAG_CALL_METADATA: typing.ClassVar[int] = ...
    RESULT_CANCELED: typing.ClassVar[int] = ...
    RESULT_DISCOVERY_TIMEOUT: typing.ClassVar[int] = ...
    RESULT_INTERNAL_ERROR: typing.ClassVar[int] = ...
    RESULT_OK: typing.ClassVar[int] = ...
    RESULT_SECURITY_ERROR: typing.ClassVar[int] = ...
    RESULT_USER_REJECTED: typing.ClassVar[int] = ...
    @typing.overload
    def associate(self, request: AssociationRequest, callback: CompanionDeviceManager.Callback, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def associate(self, request: AssociationRequest, executor: java.util.concurrent.Executor, callback: CompanionDeviceManager.Callback, /) -> None: ...
    def attachSystemDataTransport(self, associationId: int | java.jint | java.lang.Integer, in_: java.io.InputStream, out: java.io.OutputStream, /) -> None: ...
    def buildAssociationCancellationIntent(self) -> android.content.IntentSender | None: ...
    def buildPermissionTransferUserConsentIntent(self, associationId: int | java.jint | java.lang.Integer, /) -> android.content.IntentSender | None: ...
    def detachSystemDataTransport(self, associationId: int | java.jint | java.lang.Integer, /) -> None: ...
    def disableSystemDataSyncForTypes(self, associationId: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def disassociate(self, associationId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def disassociate(self, deviceMacAddress: str | java.lang.String, /) -> None: ...
    def enableSystemDataSyncForTypes(self, associationId: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAssociations(self) -> java.util.List[java.lang.String]: ...
    def getMyAssociations(self) -> java.util.List[AssociationInfo]: ...
    def hasNotificationAccess(self, component: android.content.ComponentName, /) -> bool: ...
    def isPermissionTransferUserConsented(self, associationId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def removeBond(self, associationId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def requestNotificationAccess(self, component: android.content.ComponentName, /) -> None: ...
    def setDeviceId(self, associationId: int | java.jint | java.lang.Integer, deviceId: DeviceId, /) -> None: ...
    @typing.overload
    def startObservingDevicePresence(self, request: ObservingDevicePresenceRequest, /) -> None: ...
    @typing.overload
    def startObservingDevicePresence(self, deviceAddress: str | java.lang.String, /) -> None: ...
    def startSystemDataTransfer(self, associationId: int | java.jint | java.lang.Integer, executor: java.util.concurrent.Executor, result: android.os.OutcomeReceiver[java.lang.Void, CompanionException], /) -> None: ...
    @typing.overload
    def stopObservingDevicePresence(self, request: ObservingDevicePresenceRequest, /) -> None: ...
    @typing.overload
    def stopObservingDevicePresence(self, deviceAddress: str | java.lang.String, /) -> None: ...

    class Callback(java.lang.Object):
        def __init__(self) -> None: ...
        def onAssociationCreated(self, associationInfo: AssociationInfo, /) -> None: ...
        def onAssociationPending(self, intentSender: android.content.IntentSender, /) -> None: ...
        def onDeviceFound(self, intentSender: android.content.IntentSender, /) -> None: ...
        @typing.overload
        def onFailure(self, arg1: java.lang.CharSequence, /) -> None: ...
        @typing.overload
        def onFailure(self, errorCode: int | java.jint | java.lang.Integer, error: java.lang.CharSequence, /) -> None: ...

class CompanionDeviceService(android.app.Service):
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def attachSystemDataTransport(self, associationId: int | java.jint | java.lang.Integer, in_: java.io.InputStream, out: java.io.OutputStream, /) -> None: ...
    def detachSystemDataTransport(self, associationId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder | None: ...
    @typing.overload
    def onDeviceAppeared(self, associationInfo: AssociationInfo, /) -> None: ...
    @typing.overload
    def onDeviceAppeared(self, address: str | java.lang.String, /) -> None: ...
    @typing.overload
    def onDeviceDisappeared(self, associationInfo: AssociationInfo, /) -> None: ...
    @typing.overload
    def onDeviceDisappeared(self, address: str | java.lang.String, /) -> None: ...
    def onDevicePresenceEvent(self, event: DevicePresenceEvent, /) -> None: ...

class CompanionException(java.lang.RuntimeException): ...

_DeviceFilter__D = typing.TypeVar('_DeviceFilter__D')  # <D>
class DeviceFilter(android.os.Parcelable, typing.Generic[_DeviceFilter__D]): ...

class DeviceId(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DeviceId]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCustomId(self) -> str: ...
    def getMacAddress(self) -> android.net.MacAddress: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> DeviceId: ...
        def setCustomId(self, customId: str | java.lang.String, /) -> DeviceId.Builder: ...
        def setMacAddress(self, macAddress: android.net.MacAddress, /) -> DeviceId.Builder: ...

class DeviceNotAssociatedException(java.lang.RuntimeException): ...

class DevicePresenceEvent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DevicePresenceEvent]] = ...
    EVENT_BLE_APPEARED: typing.ClassVar[int] = ...
    EVENT_BLE_DISAPPEARED: typing.ClassVar[int] = ...
    EVENT_BT_CONNECTED: typing.ClassVar[int] = ...
    EVENT_BT_DISCONNECTED: typing.ClassVar[int] = ...
    EVENT_SELF_MANAGED_APPEARED: typing.ClassVar[int] = ...
    EVENT_SELF_MANAGED_DISAPPEARED: typing.ClassVar[int] = ...
    NO_ASSOCIATION: typing.ClassVar[int] = ...
    def __init__(self, associationId: int | java.jint | java.lang.Integer, event: int | java.jint | java.lang.Integer, uuid: android.os.ParcelUuid, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAssociationId(self) -> int: ...
    def getEvent(self) -> int: ...
    def getUuid(self) -> android.os.ParcelUuid: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ObservingDevicePresenceRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ObservingDevicePresenceRequest]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAssociationId(self) -> int: ...
    def getUuid(self) -> android.os.ParcelUuid: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> ObservingDevicePresenceRequest: ...
        def setAssociationId(self, associationId: int | java.jint | java.lang.Integer, /) -> ObservingDevicePresenceRequest.Builder: ...
        def setUuid(self, uuid: android.os.ParcelUuid, /) -> ObservingDevicePresenceRequest.Builder: ...

class WifiDeviceFilter(DeviceFilter[android.net.wifi.ScanResult]):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiDeviceFilter]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> WifiDeviceFilter: ...
        def setBssid(self, value: android.net.MacAddress, /) -> WifiDeviceFilter.Builder: ...
        def setBssidMask(self, value: android.net.MacAddress, /) -> WifiDeviceFilter.Builder: ...
        def setNamePattern(self, value: java.util.regex.Pattern, /) -> WifiDeviceFilter.Builder: ...



import typing

import android.os
import android.util
import java
import java.chaquopy
import java.lang
import java.util

class BundleSession(java.lang.AutoCloseable):
    KEY_STATSD_ATOM: typing.ClassVar[str] = ...
    def close(self) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSessionId(self) -> LogSessionId: ...
    def hashCode(self) -> int: ...
    def reportBundleMetrics(self, metrics: android.os.PersistableBundle, /) -> None: ...

class EditingEndedEvent(Event, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[EditingEndedEvent]] = ...
    ERROR_CODE_AUDIO_PROCESSING_FAILED: typing.ClassVar[int] = ...
    ERROR_CODE_DECODER_INIT_FAILED: typing.ClassVar[int] = ...
    ERROR_CODE_DECODING_FAILED: typing.ClassVar[int] = ...
    ERROR_CODE_DECODING_FORMAT_UNSUPPORTED: typing.ClassVar[int] = ...
    ERROR_CODE_ENCODER_INIT_FAILED: typing.ClassVar[int] = ...
    ERROR_CODE_ENCODING_FAILED: typing.ClassVar[int] = ...
    ERROR_CODE_ENCODING_FORMAT_UNSUPPORTED: typing.ClassVar[int] = ...
    ERROR_CODE_FAILED_RUNTIME_CHECK: typing.ClassVar[int] = ...
    ERROR_CODE_IO_BAD_HTTP_STATUS: typing.ClassVar[int] = ...
    ERROR_CODE_IO_CLEARTEXT_NOT_PERMITTED: typing.ClassVar[int] = ...
    ERROR_CODE_IO_FILE_NOT_FOUND: typing.ClassVar[int] = ...
    ERROR_CODE_IO_NETWORK_CONNECTION_FAILED: typing.ClassVar[int] = ...
    ERROR_CODE_IO_NETWORK_CONNECTION_TIMEOUT: typing.ClassVar[int] = ...
    ERROR_CODE_IO_NO_PERMISSION: typing.ClassVar[int] = ...
    ERROR_CODE_IO_READ_POSITION_OUT_OF_RANGE: typing.ClassVar[int] = ...
    ERROR_CODE_IO_UNSPECIFIED: typing.ClassVar[int] = ...
    ERROR_CODE_MUXING_FAILED: typing.ClassVar[int] = ...
    ERROR_CODE_NONE: typing.ClassVar[int] = ...
    ERROR_CODE_VIDEO_FRAME_PROCESSING_FAILED: typing.ClassVar[int] = ...
    FINAL_STATE_CANCELED: typing.ClassVar[int] = ...
    FINAL_STATE_ERROR: typing.ClassVar[int] = ...
    FINAL_STATE_SUCCEEDED: typing.ClassVar[int] = ...
    OPERATION_TYPE_AUDIO_EDIT: typing.ClassVar[int] = ...
    OPERATION_TYPE_AUDIO_TRANSCODE: typing.ClassVar[int] = ...
    OPERATION_TYPE_AUDIO_TRANSMUX: typing.ClassVar[int] = ...
    OPERATION_TYPE_PAUSED: typing.ClassVar[int] = ...
    OPERATION_TYPE_RESUMED: typing.ClassVar[int] = ...
    OPERATION_TYPE_VIDEO_EDIT: typing.ClassVar[int] = ...
    OPERATION_TYPE_VIDEO_TRANSCODE: typing.ClassVar[int] = ...
    OPERATION_TYPE_VIDEO_TRANSMUX: typing.ClassVar[int] = ...
    PROGRESS_PERCENT_UNKNOWN: typing.ClassVar[int] = ...
    TIME_SINCE_CREATED_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getErrorCode(self) -> int: ...
    def getExporterName(self) -> str | None: ...
    def getFinalProgressPercent(self) -> float: ...
    def getFinalState(self) -> int: ...
    def getInputMediaItemInfos(self) -> java.util.List[MediaItemInfo]: ...
    def getMetricsBundle(self) -> android.os.Bundle: ...
    def getMuxerName(self) -> str | None: ...
    def getOperationTypes(self) -> int: ...
    def getOutputMediaItemInfo(self) -> MediaItemInfo | None: ...
    def getTimeSinceCreatedMillis(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, finalState: int | java.jint | java.lang.Integer, /) -> None: ...
        def addInputMediaItemInfo(self, mediaItemInfo: MediaItemInfo, /) -> EditingEndedEvent.Builder: ...
        def addOperationType(self, operationType: int | java.jlong | java.lang.Long, /) -> EditingEndedEvent.Builder: ...
        def build(self) -> EditingEndedEvent: ...
        def setErrorCode(self, value: int | java.jint | java.lang.Integer, /) -> EditingEndedEvent.Builder: ...
        def setExporterName(self, exporterName: str | java.lang.String, /) -> EditingEndedEvent.Builder: ...
        def setFinalProgressPercent(self, finalProgressPercent: float | java.jfloat | java.lang.Float, /) -> EditingEndedEvent.Builder: ...
        def setMetricsBundle(self, metricsBundle: android.os.Bundle, /) -> EditingEndedEvent.Builder: ...
        def setMuxerName(self, muxerName: str | java.lang.String, /) -> EditingEndedEvent.Builder: ...
        def setOutputMediaItemInfo(self, mediaItemInfo: MediaItemInfo, /) -> EditingEndedEvent.Builder: ...
        def setTimeSinceCreatedMillis(self, timeSinceCreatedMillis: int | java.jlong | java.lang.Long, /) -> EditingEndedEvent.Builder: ...

class EditingSession(java.lang.AutoCloseable):
    def close(self) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSessionId(self) -> LogSessionId: ...
    def hashCode(self) -> int: ...
    def reportEditingEndedEvent(self, editingEndedEvent: EditingEndedEvent, /) -> None: ...

class Event(java.lang.Object):
    def getMetricsBundle(self) -> android.os.Bundle: ...
    def getTimeSinceCreatedMillis(self) -> int: ...

class LogSessionId(java.lang.Object):
    LOG_SESSION_ID_NONE: typing.ClassVar[LogSessionId] = ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getStringId(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class MediaItemInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MediaItemInfo]] = ...
    DATA_TYPE_AUDIO: typing.ClassVar[int] = ...
    DATA_TYPE_DEPTH: typing.ClassVar[int] = ...
    DATA_TYPE_GAIN_MAP: typing.ClassVar[int] = ...
    DATA_TYPE_GAPLESS: typing.ClassVar[int] = ...
    DATA_TYPE_HIGH_DYNAMIC_RANGE_VIDEO: typing.ClassVar[int] = ...
    DATA_TYPE_HIGH_FRAME_RATE: typing.ClassVar[int] = ...
    DATA_TYPE_IMAGE: typing.ClassVar[int] = ...
    DATA_TYPE_METADATA: typing.ClassVar[int] = ...
    DATA_TYPE_SPATIAL_AUDIO: typing.ClassVar[int] = ...
    DATA_TYPE_SPEED_SETTING_CUE_POINTS: typing.ClassVar[int] = ...
    DATA_TYPE_VIDEO: typing.ClassVar[int] = ...
    SOURCE_TYPE_CAMERA: typing.ClassVar[int] = ...
    SOURCE_TYPE_EDITING_SESSION: typing.ClassVar[int] = ...
    SOURCE_TYPE_GALLERY: typing.ClassVar[int] = ...
    SOURCE_TYPE_GENERATED: typing.ClassVar[int] = ...
    SOURCE_TYPE_LOCAL_FILE: typing.ClassVar[int] = ...
    SOURCE_TYPE_REMOTE_FILE: typing.ClassVar[int] = ...
    SOURCE_TYPE_REMOTE_LIVE_STREAM: typing.ClassVar[int] = ...
    SOURCE_TYPE_UNSPECIFIED: typing.ClassVar[int] = ...
    VALUE_UNSPECIFIED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAudioChannelCount(self) -> int: ...
    def getAudioSampleCount(self) -> int: ...
    def getAudioSampleRateHz(self) -> int: ...
    def getClipDurationMillis(self) -> int: ...
    def getCodecNames(self) -> java.util.List[java.lang.String]: ...
    def getContainerMimeType(self) -> str | None: ...
    def getDataTypes(self) -> int: ...
    def getDurationMillis(self) -> int: ...
    def getSampleMimeTypes(self) -> java.util.List[java.lang.String]: ...
    def getSourceType(self) -> int: ...
    def getVideoDataSpace(self) -> int: ...
    def getVideoFrameRate(self) -> float: ...
    def getVideoSampleCount(self) -> int: ...
    def getVideoSize(self) -> android.util.Size: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addCodecName(self, codecName: str | java.lang.String, /) -> MediaItemInfo.Builder: ...
        def addDataType(self, dataType: int | java.jlong | java.lang.Long, /) -> MediaItemInfo.Builder: ...
        def addSampleMimeType(self, mimeType: str | java.lang.String, /) -> MediaItemInfo.Builder: ...
        def build(self) -> MediaItemInfo: ...
        def setAudioChannelCount(self, audioChannelCount: int | java.jint | java.lang.Integer, /) -> MediaItemInfo.Builder: ...
        def setAudioSampleCount(self, audioSampleCount: int | java.jlong | java.lang.Long, /) -> MediaItemInfo.Builder: ...
        def setAudioSampleRateHz(self, audioSampleRateHz: int | java.jint | java.lang.Integer, /) -> MediaItemInfo.Builder: ...
        def setClipDurationMillis(self, clipDurationMillis: int | java.jlong | java.lang.Long, /) -> MediaItemInfo.Builder: ...
        def setContainerMimeType(self, containerMimeType: str | java.lang.String, /) -> MediaItemInfo.Builder: ...
        def setDurationMillis(self, durationMillis: int | java.jlong | java.lang.Long, /) -> MediaItemInfo.Builder: ...
        def setSourceType(self, sourceType: int | java.jint | java.lang.Integer, /) -> MediaItemInfo.Builder: ...
        def setVideoDataSpace(self, videoDataSpace: int | java.jint | java.lang.Integer, /) -> MediaItemInfo.Builder: ...
        def setVideoFrameRate(self, videoFrameRate: float | java.jfloat | java.lang.Float, /) -> MediaItemInfo.Builder: ...
        def setVideoSampleCount(self, videoSampleCount: int | java.jlong | java.lang.Long, /) -> MediaItemInfo.Builder: ...
        def setVideoSize(self, videoSize: android.util.Size, /) -> MediaItemInfo.Builder: ...

class MediaMetricsManager(java.lang.Object):
    INVALID_TIMESTAMP: typing.ClassVar[int] = ...
    def createBundleSession(self) -> BundleSession: ...
    def createEditingSession(self) -> EditingSession: ...
    def createPlaybackSession(self) -> PlaybackSession: ...
    def createRecordingSession(self) -> RecordingSession: ...
    def createTranscodingSession(self) -> TranscodingSession: ...
    def releaseSessionId(self, sessionId: str | java.lang.String, /) -> None: ...

class NetworkEvent(Event, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NetworkEvent]] = ...
    NETWORK_TYPE_2G: typing.ClassVar[int] = ...
    NETWORK_TYPE_3G: typing.ClassVar[int] = ...
    NETWORK_TYPE_4G: typing.ClassVar[int] = ...
    NETWORK_TYPE_5G_NSA: typing.ClassVar[int] = ...
    NETWORK_TYPE_5G_SA: typing.ClassVar[int] = ...
    NETWORK_TYPE_ETHERNET: typing.ClassVar[int] = ...
    NETWORK_TYPE_OFFLINE: typing.ClassVar[int] = ...
    NETWORK_TYPE_OTHER: typing.ClassVar[int] = ...
    NETWORK_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    NETWORK_TYPE_WIFI: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMetricsBundle(self) -> android.os.Bundle: ...
    def getNetworkType(self) -> int: ...
    def getTimeSinceCreatedMillis(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> NetworkEvent: ...
        def setMetricsBundle(self, metricsBundle: android.os.Bundle, /) -> NetworkEvent.Builder: ...
        def setNetworkType(self, value: int | java.jint | java.lang.Integer, /) -> NetworkEvent.Builder: ...
        def setTimeSinceCreatedMillis(self, value: int | java.jlong | java.lang.Long, /) -> NetworkEvent.Builder: ...

class PlaybackErrorEvent(Event, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PlaybackErrorEvent]] = ...
    ERROR_AUDIO_TRACK_INIT_FAILED: typing.ClassVar[int] = ...
    ERROR_AUDIO_TRACK_OTHER: typing.ClassVar[int] = ...
    ERROR_AUDIO_TRACK_WRITE_FAILED: typing.ClassVar[int] = ...
    ERROR_DECODER_INIT_FAILED: typing.ClassVar[int] = ...
    ERROR_DECODING_FAILED: typing.ClassVar[int] = ...
    ERROR_DECODING_FORMAT_EXCEEDS_CAPABILITIES: typing.ClassVar[int] = ...
    ERROR_DECODING_FORMAT_UNSUPPORTED: typing.ClassVar[int] = ...
    ERROR_DECODING_OTHER: typing.ClassVar[int] = ...
    ERROR_DRM_CONTENT_ERROR: typing.ClassVar[int] = ...
    ERROR_DRM_DEVICE_REVOKED: typing.ClassVar[int] = ...
    ERROR_DRM_DISALLOWED_OPERATION: typing.ClassVar[int] = ...
    ERROR_DRM_LICENSE_ACQUISITION_FAILED: typing.ClassVar[int] = ...
    ERROR_DRM_OTHER: typing.ClassVar[int] = ...
    ERROR_DRM_PROVISIONING_FAILED: typing.ClassVar[int] = ...
    ERROR_DRM_SCHEME_UNSUPPORTED: typing.ClassVar[int] = ...
    ERROR_DRM_SYSTEM_ERROR: typing.ClassVar[int] = ...
    ERROR_IO_BAD_HTTP_STATUS: typing.ClassVar[int] = ...
    ERROR_IO_CONNECTION_CLOSED: typing.ClassVar[int] = ...
    ERROR_IO_CONNECTION_TIMEOUT: typing.ClassVar[int] = ...
    ERROR_IO_DNS_FAILED: typing.ClassVar[int] = ...
    ERROR_IO_FILE_NOT_FOUND: typing.ClassVar[int] = ...
    ERROR_IO_NETWORK_CONNECTION_FAILED: typing.ClassVar[int] = ...
    ERROR_IO_NETWORK_UNAVAILABLE: typing.ClassVar[int] = ...
    ERROR_IO_NO_PERMISSION: typing.ClassVar[int] = ...
    ERROR_IO_OTHER: typing.ClassVar[int] = ...
    ERROR_OTHER: typing.ClassVar[int] = ...
    ERROR_PARSING_CONTAINER_MALFORMED: typing.ClassVar[int] = ...
    ERROR_PARSING_CONTAINER_UNSUPPORTED: typing.ClassVar[int] = ...
    ERROR_PARSING_MANIFEST_MALFORMED: typing.ClassVar[int] = ...
    ERROR_PARSING_MANIFEST_UNSUPPORTED: typing.ClassVar[int] = ...
    ERROR_PARSING_OTHER: typing.ClassVar[int] = ...
    ERROR_PLAYER_BEHIND_LIVE_WINDOW: typing.ClassVar[int] = ...
    ERROR_PLAYER_OTHER: typing.ClassVar[int] = ...
    ERROR_PLAYER_REMOTE: typing.ClassVar[int] = ...
    ERROR_RUNTIME: typing.ClassVar[int] = ...
    ERROR_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getErrorCode(self) -> int: ...
    def getMetricsBundle(self) -> android.os.Bundle: ...
    def getSubErrorCode(self) -> int: ...
    def getTimeSinceCreatedMillis(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> PlaybackErrorEvent: ...
        def setErrorCode(self, value: int | java.jint | java.lang.Integer, /) -> PlaybackErrorEvent.Builder: ...
        def setException(self, value: java.lang.Exception, /) -> PlaybackErrorEvent.Builder: ...
        def setMetricsBundle(self, metricsBundle: android.os.Bundle, /) -> PlaybackErrorEvent.Builder: ...
        def setSubErrorCode(self, value: int | java.jint | java.lang.Integer, /) -> PlaybackErrorEvent.Builder: ...
        def setTimeSinceCreatedMillis(self, value: int | java.jlong | java.lang.Long, /) -> PlaybackErrorEvent.Builder: ...

class PlaybackMetrics(android.os.Parcelable):
    CONTENT_TYPE_AD: typing.ClassVar[int] = ...
    CONTENT_TYPE_MAIN: typing.ClassVar[int] = ...
    CONTENT_TYPE_OTHER: typing.ClassVar[int] = ...
    CONTENT_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PlaybackMetrics]] = ...
    DRM_TYPE_CLEARKEY: typing.ClassVar[int] = ...
    DRM_TYPE_NONE: typing.ClassVar[int] = ...
    DRM_TYPE_OTHER: typing.ClassVar[int] = ...
    DRM_TYPE_PLAY_READY: typing.ClassVar[int] = ...
    DRM_TYPE_WIDEVINE_L1: typing.ClassVar[int] = ...
    DRM_TYPE_WIDEVINE_L3: typing.ClassVar[int] = ...
    DRM_TYPE_WV_L3_FALLBACK: typing.ClassVar[int] = ...
    PLAYBACK_TYPE_LIVE: typing.ClassVar[int] = ...
    PLAYBACK_TYPE_OTHER: typing.ClassVar[int] = ...
    PLAYBACK_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    PLAYBACK_TYPE_VOD: typing.ClassVar[int] = ...
    STREAM_SOURCE_DEVICE: typing.ClassVar[int] = ...
    STREAM_SOURCE_MIXED: typing.ClassVar[int] = ...
    STREAM_SOURCE_NETWORK: typing.ClassVar[int] = ...
    STREAM_SOURCE_UNKNOWN: typing.ClassVar[int] = ...
    STREAM_TYPE_DASH: typing.ClassVar[int] = ...
    STREAM_TYPE_HLS: typing.ClassVar[int] = ...
    STREAM_TYPE_OTHER: typing.ClassVar[int] = ...
    STREAM_TYPE_PROGRESSIVE: typing.ClassVar[int] = ...
    STREAM_TYPE_SS: typing.ClassVar[int] = ...
    STREAM_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAudioUnderrunCount(self) -> int: ...
    def getContentType(self) -> int: ...
    def getDrmSessionId(self) -> java.chaquopy.JavaArrayJByte: ...
    def getDrmType(self) -> int: ...
    def getExperimentIds(self) -> java.chaquopy.JavaArrayJLong: ...
    def getLocalBytesRead(self) -> int: ...
    def getMediaDurationMillis(self) -> int: ...
    def getMetricsBundle(self) -> android.os.Bundle: ...
    def getNetworkBytesRead(self) -> int: ...
    def getNetworkTransferDurationMillis(self) -> int: ...
    def getPlaybackType(self) -> int: ...
    def getPlayerName(self) -> str | None: ...
    def getPlayerVersion(self) -> str | None: ...
    def getStreamSource(self) -> int: ...
    def getStreamType(self) -> int: ...
    def getVideoFramesDropped(self) -> int: ...
    def getVideoFramesPlayed(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addExperimentId(self, value: int | java.jlong | java.lang.Long, /) -> PlaybackMetrics.Builder: ...
        def build(self) -> PlaybackMetrics: ...
        def setAudioUnderrunCount(self, value: int | java.jint | java.lang.Integer, /) -> PlaybackMetrics.Builder: ...
        def setContentType(self, value: int | java.jint | java.lang.Integer, /) -> PlaybackMetrics.Builder: ...
        def setDrmSessionId(self, drmSessionId: java.chaquopy.JavaArrayJByte, /) -> PlaybackMetrics.Builder: ...
        def setDrmType(self, value: int | java.jint | java.lang.Integer, /) -> PlaybackMetrics.Builder: ...
        def setLocalBytesRead(self, value: int | java.jlong | java.lang.Long, /) -> PlaybackMetrics.Builder: ...
        def setMediaDurationMillis(self, value: int | java.jlong | java.lang.Long, /) -> PlaybackMetrics.Builder: ...
        def setMetricsBundle(self, metricsBundle: android.os.Bundle, /) -> PlaybackMetrics.Builder: ...
        def setNetworkBytesRead(self, value: int | java.jlong | java.lang.Long, /) -> PlaybackMetrics.Builder: ...
        def setNetworkTransferDurationMillis(self, value: int | java.jlong | java.lang.Long, /) -> PlaybackMetrics.Builder: ...
        def setPlaybackType(self, value: int | java.jint | java.lang.Integer, /) -> PlaybackMetrics.Builder: ...
        def setPlayerName(self, value: str | java.lang.String, /) -> PlaybackMetrics.Builder: ...
        def setPlayerVersion(self, value: str | java.lang.String, /) -> PlaybackMetrics.Builder: ...
        def setStreamSource(self, value: int | java.jint | java.lang.Integer, /) -> PlaybackMetrics.Builder: ...
        def setStreamType(self, value: int | java.jint | java.lang.Integer, /) -> PlaybackMetrics.Builder: ...
        def setVideoFramesDropped(self, value: int | java.jint | java.lang.Integer, /) -> PlaybackMetrics.Builder: ...
        def setVideoFramesPlayed(self, value: int | java.jint | java.lang.Integer, /) -> PlaybackMetrics.Builder: ...

class PlaybackSession(java.lang.AutoCloseable):
    def close(self) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSessionId(self) -> LogSessionId: ...
    def hashCode(self) -> int: ...
    def reportNetworkEvent(self, event: NetworkEvent, /) -> None: ...
    def reportPlaybackErrorEvent(self, event: PlaybackErrorEvent, /) -> None: ...
    def reportPlaybackMetrics(self, metrics: PlaybackMetrics, /) -> None: ...
    def reportPlaybackStateEvent(self, event: PlaybackStateEvent, /) -> None: ...
    def reportTrackChangeEvent(self, event: TrackChangeEvent, /) -> None: ...

class PlaybackStateEvent(Event, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PlaybackStateEvent]] = ...
    STATE_ABANDONED: typing.ClassVar[int] = ...
    STATE_BUFFERING: typing.ClassVar[int] = ...
    STATE_ENDED: typing.ClassVar[int] = ...
    STATE_FAILED: typing.ClassVar[int] = ...
    STATE_INTERRUPTED_BY_AD: typing.ClassVar[int] = ...
    STATE_JOINING_BACKGROUND: typing.ClassVar[int] = ...
    STATE_JOINING_FOREGROUND: typing.ClassVar[int] = ...
    STATE_NOT_STARTED: typing.ClassVar[int] = ...
    STATE_PAUSED: typing.ClassVar[int] = ...
    STATE_PAUSED_BUFFERING: typing.ClassVar[int] = ...
    STATE_PLAYING: typing.ClassVar[int] = ...
    STATE_SEEKING: typing.ClassVar[int] = ...
    STATE_STOPPED: typing.ClassVar[int] = ...
    STATE_SUPPRESSED: typing.ClassVar[int] = ...
    STATE_SUPPRESSED_BUFFERING: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMetricsBundle(self) -> android.os.Bundle: ...
    def getState(self) -> int: ...
    def getTimeSinceCreatedMillis(self) -> int: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> PlaybackStateEvent: ...
        def setMetricsBundle(self, metricsBundle: android.os.Bundle, /) -> PlaybackStateEvent.Builder: ...
        def setState(self, value: int | java.jint | java.lang.Integer, /) -> PlaybackStateEvent.Builder: ...
        def setTimeSinceCreatedMillis(self, value: int | java.jlong | java.lang.Long, /) -> PlaybackStateEvent.Builder: ...

class RecordingSession(java.lang.AutoCloseable):
    def close(self) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSessionId(self) -> LogSessionId: ...
    def hashCode(self) -> int: ...

class TrackChangeEvent(Event, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TrackChangeEvent]] = ...
    TRACK_CHANGE_REASON_ADAPTIVE: typing.ClassVar[int] = ...
    TRACK_CHANGE_REASON_INITIAL: typing.ClassVar[int] = ...
    TRACK_CHANGE_REASON_MANUAL: typing.ClassVar[int] = ...
    TRACK_CHANGE_REASON_OTHER: typing.ClassVar[int] = ...
    TRACK_CHANGE_REASON_UNKNOWN: typing.ClassVar[int] = ...
    TRACK_STATE_OFF: typing.ClassVar[int] = ...
    TRACK_STATE_ON: typing.ClassVar[int] = ...
    TRACK_TYPE_AUDIO: typing.ClassVar[int] = ...
    TRACK_TYPE_TEXT: typing.ClassVar[int] = ...
    TRACK_TYPE_VIDEO: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAudioSampleRate(self) -> int: ...
    def getBitrate(self) -> int: ...
    def getChannelCount(self) -> int: ...
    def getCodecName(self) -> str | None: ...
    def getContainerMimeType(self) -> str | None: ...
    def getHeight(self) -> int: ...
    def getLanguage(self) -> str | None: ...
    def getLanguageRegion(self) -> str | None: ...
    def getMetricsBundle(self) -> android.os.Bundle: ...
    def getSampleMimeType(self) -> str | None: ...
    def getTimeSinceCreatedMillis(self) -> int: ...
    def getTrackChangeReason(self) -> int: ...
    def getTrackState(self) -> int: ...
    def getTrackType(self) -> int: ...
    def getVideoFrameRate(self) -> float: ...
    def getWidth(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, type: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> TrackChangeEvent: ...
        def setAudioSampleRate(self, value: int | java.jint | java.lang.Integer, /) -> TrackChangeEvent.Builder: ...
        def setBitrate(self, value: int | java.jint | java.lang.Integer, /) -> TrackChangeEvent.Builder: ...
        def setChannelCount(self, value: int | java.jint | java.lang.Integer, /) -> TrackChangeEvent.Builder: ...
        def setCodecName(self, value: str | java.lang.String, /) -> TrackChangeEvent.Builder: ...
        def setContainerMimeType(self, value: str | java.lang.String, /) -> TrackChangeEvent.Builder: ...
        def setHeight(self, value: int | java.jint | java.lang.Integer, /) -> TrackChangeEvent.Builder: ...
        def setLanguage(self, value: str | java.lang.String, /) -> TrackChangeEvent.Builder: ...
        def setLanguageRegion(self, value: str | java.lang.String, /) -> TrackChangeEvent.Builder: ...
        def setMetricsBundle(self, metricsBundle: android.os.Bundle, /) -> TrackChangeEvent.Builder: ...
        def setSampleMimeType(self, value: str | java.lang.String, /) -> TrackChangeEvent.Builder: ...
        def setTimeSinceCreatedMillis(self, value: int | java.jlong | java.lang.Long, /) -> TrackChangeEvent.Builder: ...
        def setTrackChangeReason(self, value: int | java.jint | java.lang.Integer, /) -> TrackChangeEvent.Builder: ...
        def setTrackState(self, value: int | java.jint | java.lang.Integer, /) -> TrackChangeEvent.Builder: ...
        def setVideoFrameRate(self, value: float | java.jfloat | java.lang.Float, /) -> TrackChangeEvent.Builder: ...
        def setWidth(self, value: int | java.jint | java.lang.Integer, /) -> TrackChangeEvent.Builder: ...

class TranscodingSession(java.lang.AutoCloseable):
    def close(self) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSessionId(self) -> LogSessionId: ...
    def hashCode(self) -> int: ...



import typing

import android.app
import android.content
import android.content.pm
import android.graphics
import android.media.tv
import android.net
import android.os
import android.util
import android.view
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class TvAdManager(java.lang.Object):
    ACTION_APP_LINK_COMMAND: typing.ClassVar[str] = ...
    APP_LINK_KEY_BACK_URI: typing.ClassVar[str] = ...
    APP_LINK_KEY_CLASS_NAME: typing.ClassVar[str] = ...
    APP_LINK_KEY_COMMAND_TYPE: typing.ClassVar[str] = ...
    APP_LINK_KEY_PACKAGE_NAME: typing.ClassVar[str] = ...
    APP_LINK_KEY_SERVICE_ID: typing.ClassVar[str] = ...
    ERROR_BLOCKED: typing.ClassVar[int] = ...
    ERROR_ENCRYPTED: typing.ClassVar[int] = ...
    ERROR_NONE: typing.ClassVar[int] = ...
    ERROR_NOT_SUPPORTED: typing.ClassVar[int] = ...
    ERROR_RESOURCE_UNAVAILABLE: typing.ClassVar[int] = ...
    ERROR_UNKNOWN: typing.ClassVar[int] = ...
    ERROR_UNKNOWN_CHANNEL: typing.ClassVar[int] = ...
    ERROR_WEAK_SIGNAL: typing.ClassVar[int] = ...
    INTENT_KEY_AD_SERVICE_ID: typing.ClassVar[str] = ...
    INTENT_KEY_CHANNEL_URI: typing.ClassVar[str] = ...
    INTENT_KEY_COMMAND_TYPE: typing.ClassVar[str] = ...
    INTENT_KEY_TV_INPUT_ID: typing.ClassVar[str] = ...
    SESSION_DATA_KEY_AD_BUFFER: typing.ClassVar[str] = ...
    SESSION_DATA_KEY_AD_REQUEST: typing.ClassVar[str] = ...
    SESSION_DATA_KEY_BROADCAST_INFO_REQUEST: typing.ClassVar[str] = ...
    SESSION_DATA_KEY_REQUEST_ID: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_AD_BUFFER_READY: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_AD_REQUEST: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_BROADCAST_INFO_REQUEST: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_REMOVE_BROADCAST_INFO_REQUEST: typing.ClassVar[str] = ...
    SESSION_STATE_ERROR: typing.ClassVar[int] = ...
    SESSION_STATE_RUNNING: typing.ClassVar[int] = ...
    SESSION_STATE_STOPPED: typing.ClassVar[int] = ...
    def getTvAdServiceList(self) -> java.util.List[TvAdServiceInfo]: ...
    def registerCallback(self, executor: java.util.concurrent.Executor, callback: TvAdManager.TvAdServiceCallback, /) -> None: ...
    def sendAppLinkCommand(self, serviceId: str | java.lang.String, command: android.os.Bundle, /) -> None: ...
    def unregisterCallback(self, callback: TvAdManager.TvAdServiceCallback, /) -> None: ...

    class TvAdServiceCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onAdServiceAdded(self, serviceId: str | java.lang.String, /) -> None: ...
        def onAdServiceRemoved(self, serviceId: str | java.lang.String, /) -> None: ...
        def onAdServiceUpdated(self, serviceId: str | java.lang.String, /) -> None: ...

class TvAdService(android.app.Service):
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    SERVICE_META_DATA: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def onAppLinkCommand(self, command: android.os.Bundle, /) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onCreateSession(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> TvAdService.Session: ...

    class Session(android.view.KeyEvent.Callback):
        def __init__(self, context: android.content.Context, /) -> None: ...
        def isMediaViewEnabled(self) -> bool: ...
        def layoutSurface(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
        def notifySessionStateChanged(self, state: int | java.jint | java.lang.Integer, err: int | java.jint | java.lang.Integer, /) -> None: ...
        def onCreateMediaView(self) -> android.view.View: ...
        def onCurrentChannelUri(self, channelUri: android.net.Uri, /) -> None: ...
        def onCurrentTvInputId(self, inputId: str | java.lang.String, /) -> None: ...
        def onCurrentVideoBounds(self, bounds: android.graphics.Rect, /) -> None: ...
        def onError(self, errMsg: str | java.lang.String, params: android.os.Bundle, /) -> None: ...
        def onGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
        def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
        def onKeyLongPress(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
        def onKeyMultiple(self, keyCode: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
        def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
        def onMediaViewSizeChanged(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        def onRelease(self) -> None: ...
        def onResetAdService(self) -> None: ...
        def onSetSurface(self, arg1: android.view.Surface, /) -> bool: ...
        def onSigningResult(self, signingId: str | java.lang.String, result: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def onStartAdService(self) -> None: ...
        def onStopAdService(self) -> None: ...
        def onSurfaceChanged(self, format: int | java.jint | java.lang.Integer, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
        def onTrackInfoList(self, tracks: java.util.List[android.media.tv.TvTrackInfo], /) -> None: ...
        def onTrackballEvent(self, event: android.view.MotionEvent, /) -> bool: ...
        def onTvInputSessionData(self, type: str | java.lang.String, data: android.os.Bundle, /) -> None: ...
        def onTvMessage(self, type: int | java.jint | java.lang.Integer, data: android.os.Bundle, /) -> None: ...
        def requestCurrentChannelUri(self) -> None: ...
        def requestCurrentTvInputId(self) -> None: ...
        def requestCurrentVideoBounds(self) -> None: ...
        def requestSigning(self, signingId: str | java.lang.String, algorithm: str | java.lang.String, alias: str | java.lang.String, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def requestTrackInfoList(self) -> None: ...
        def sendTvAdSessionData(self, type: str | java.lang.String, data: android.os.Bundle, /) -> None: ...
        def setMediaViewEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class TvAdServiceInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TvAdServiceInfo]] = ...
    def __init__(self, context: android.content.Context, component: android.content.ComponentName, /) -> None: ...
    def describeContents(self) -> int: ...
    def getId(self) -> str: ...
    def getServiceInfo(self) -> android.content.pm.ServiceInfo: ...
    def getSupportedTypes(self) -> java.util.List[java.lang.String]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TvAdView(android.view.ViewGroup):
    ERROR_KEY_ERROR_CODE: typing.ClassVar[str] = ...
    ERROR_KEY_METHOD_NAME: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    def clearCallback(self) -> None: ...
    def clearOnUnhandledInputEventListener(self) -> None: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def dispatchUnhandledInputEvent(self, event: android.view.InputEvent, /) -> bool: ...
    def getOnUnhandledInputEventListener(self) -> TvAdView.OnUnhandledInputEventListener: ...
    def notifyError(self, errMsg: str | java.lang.String, params: android.os.Bundle, /) -> None: ...
    def notifyTvMessage(self, type: int | java.jint | java.lang.Integer, data: android.os.Bundle, /) -> None: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onUnhandledInputEvent(self, event: android.view.InputEvent, /) -> bool: ...
    def onVisibilityChanged(self, changedView: android.view.View, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def prepareAdService(self, serviceId: str | java.lang.String, type: str | java.lang.String, /) -> None: ...
    def reset(self) -> None: ...
    def resetAdService(self) -> None: ...
    def sendCurrentChannelUri(self, channelUri: android.net.Uri, /) -> None: ...
    def sendCurrentTvInputId(self, inputId: str | java.lang.String, /) -> None: ...
    def sendCurrentVideoBounds(self, bounds: android.graphics.Rect, /) -> None: ...
    def sendSigningResult(self, signingId: str | java.lang.String, result: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def sendTrackInfoList(self, tracks: java.util.List[android.media.tv.TvTrackInfo], /) -> None: ...
    def setCallback(self, executor: java.util.concurrent.Executor, callback: TvAdView.TvAdCallback, /) -> None: ...
    def setOnUnhandledInputEventListener(self, listener: TvAdView.OnUnhandledInputEventListener, /) -> None: ...
    def setTvView(self, tvView: android.media.tv.TvView, /) -> bool: ...
    def setZOrderMediaOverlay(self, isMediaOverlay: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setZOrderOnTop(self, onTop: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def startAdService(self) -> None: ...
    def stopAdService(self) -> None: ...

    class TvAdCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onRequestCurrentChannelUri(self, serviceId: str | java.lang.String, /) -> None: ...
        def onRequestCurrentTvInputId(self, serviceId: str | java.lang.String, /) -> None: ...
        def onRequestCurrentVideoBounds(self, serviceId: str | java.lang.String, /) -> None: ...
        def onRequestSigning(self, serviceId: str | java.lang.String, signingId: str | java.lang.String, algorithm: str | java.lang.String, alias: str | java.lang.String, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def onRequestTrackInfoList(self, serviceId: str | java.lang.String, /) -> None: ...
        def onStateChanged(self, serviceId: str | java.lang.String, state: int | java.jint | java.lang.Integer, err: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnUnhandledInputEventListener(java.lang.Object):
        def onUnhandledInputEvent(self, arg1: android.view.InputEvent, /) -> bool: ...



import typing

import android.nfc
import java
import java.chaquopy
import java.io
import java.lang

class IsoDep(TagTechnology):
    def close(self) -> None: ...
    def connect(self) -> None: ...
    @staticmethod
    def get(tag: android.nfc.Tag, /) -> IsoDep: ...
    def getHiLayerResponse(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getHistoricalBytes(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getMaxTransceiveLength(self) -> int: ...
    def getTag(self) -> android.nfc.Tag: ...
    def getTimeout(self) -> int: ...
    def isConnected(self) -> bool: ...
    def isExtendedLengthApduSupported(self) -> bool: ...
    def setTimeout(self, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def transceive(self, data: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...

class MifareClassic(TagTechnology):
    BLOCK_SIZE: typing.ClassVar[int] = ...
    KEY_DEFAULT: typing.ClassVar[java.chaquopy.JavaArrayJByte] = ...
    KEY_MIFARE_APPLICATION_DIRECTORY: typing.ClassVar[java.chaquopy.JavaArrayJByte] = ...
    KEY_NFC_FORUM: typing.ClassVar[java.chaquopy.JavaArrayJByte] = ...
    SIZE_1K: typing.ClassVar[int] = ...
    SIZE_2K: typing.ClassVar[int] = ...
    SIZE_4K: typing.ClassVar[int] = ...
    SIZE_MINI: typing.ClassVar[int] = ...
    TYPE_CLASSIC: typing.ClassVar[int] = ...
    TYPE_PLUS: typing.ClassVar[int] = ...
    TYPE_PRO: typing.ClassVar[int] = ...
    TYPE_UNKNOWN: typing.ClassVar[int] = ...
    def authenticateSectorWithKeyA(self, sectorIndex: int | java.jint | java.lang.Integer, key: java.chaquopy.JavaArrayJByte, /) -> bool: ...
    def authenticateSectorWithKeyB(self, sectorIndex: int | java.jint | java.lang.Integer, key: java.chaquopy.JavaArrayJByte, /) -> bool: ...
    def blockToSector(self, blockIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def close(self) -> None: ...
    def connect(self) -> None: ...
    def decrement(self, blockIndex: int | java.jint | java.lang.Integer, value: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def get(tag: android.nfc.Tag, /) -> MifareClassic: ...
    def getBlockCount(self) -> int: ...
    def getBlockCountInSector(self, sectorIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getMaxTransceiveLength(self) -> int: ...
    def getSectorCount(self) -> int: ...
    def getSize(self) -> int: ...
    def getTag(self) -> android.nfc.Tag: ...
    def getTimeout(self) -> int: ...
    def getType(self) -> int: ...
    def increment(self, blockIndex: int | java.jint | java.lang.Integer, value: int | java.jint | java.lang.Integer, /) -> None: ...
    def isConnected(self) -> bool: ...
    def readBlock(self, blockIndex: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    def restore(self, blockIndex: int | java.jint | java.lang.Integer, /) -> None: ...
    def sectorToBlock(self, sectorIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def setTimeout(self, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def transceive(self, data: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def transfer(self, blockIndex: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBlock(self, blockIndex: int | java.jint | java.lang.Integer, data: java.chaquopy.JavaArrayJByte, /) -> None: ...

class MifareUltralight(TagTechnology):
    PAGE_SIZE: typing.ClassVar[int] = ...
    TYPE_ULTRALIGHT: typing.ClassVar[int] = ...
    TYPE_ULTRALIGHT_C: typing.ClassVar[int] = ...
    TYPE_UNKNOWN: typing.ClassVar[int] = ...
    def close(self) -> None: ...
    def connect(self) -> None: ...
    @staticmethod
    def get(tag: android.nfc.Tag, /) -> MifareUltralight: ...
    def getMaxTransceiveLength(self) -> int: ...
    def getTag(self) -> android.nfc.Tag: ...
    def getTimeout(self) -> int: ...
    def getType(self) -> int: ...
    def isConnected(self) -> bool: ...
    def readPages(self, pageOffset: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    def setTimeout(self, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def transceive(self, data: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def writePage(self, pageOffset: int | java.jint | java.lang.Integer, data: java.chaquopy.JavaArrayJByte, /) -> None: ...

class Ndef(TagTechnology):
    MIFARE_CLASSIC: typing.ClassVar[str] = ...
    NFC_FORUM_TYPE_1: typing.ClassVar[str] = ...
    NFC_FORUM_TYPE_2: typing.ClassVar[str] = ...
    NFC_FORUM_TYPE_3: typing.ClassVar[str] = ...
    NFC_FORUM_TYPE_4: typing.ClassVar[str] = ...
    def canMakeReadOnly(self) -> bool: ...
    def close(self) -> None: ...
    def connect(self) -> None: ...
    @staticmethod
    def get(tag: android.nfc.Tag, /) -> Ndef: ...
    def getCachedNdefMessage(self) -> android.nfc.NdefMessage | None: ...
    def getMaxSize(self) -> int: ...
    def getNdefMessage(self) -> android.nfc.NdefMessage | None: ...
    def getTag(self) -> android.nfc.Tag: ...
    def getType(self) -> str: ...
    def isConnected(self) -> bool: ...
    def isWritable(self) -> bool: ...
    def makeReadOnly(self) -> bool: ...
    def writeNdefMessage(self, msg: android.nfc.NdefMessage, /) -> None: ...

class NdefFormatable(TagTechnology):
    def close(self) -> None: ...
    def connect(self) -> None: ...
    def format(self, firstMessage: android.nfc.NdefMessage, /) -> None: ...
    def formatReadOnly(self, firstMessage: android.nfc.NdefMessage, /) -> None: ...
    @staticmethod
    def get(tag: android.nfc.Tag, /) -> NdefFormatable: ...
    def getTag(self) -> android.nfc.Tag: ...
    def isConnected(self) -> bool: ...

class NfcA(TagTechnology):
    def close(self) -> None: ...
    def connect(self) -> None: ...
    @staticmethod
    def get(tag: android.nfc.Tag, /) -> NfcA: ...
    def getAtqa(self) -> java.chaquopy.JavaArrayJByte: ...
    def getMaxTransceiveLength(self) -> int: ...
    def getSak(self) -> int: ...
    def getTag(self) -> android.nfc.Tag: ...
    def getTimeout(self) -> int: ...
    def isConnected(self) -> bool: ...
    def setTimeout(self, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def transceive(self, data: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...

class NfcB(TagTechnology):
    def close(self) -> None: ...
    def connect(self) -> None: ...
    @staticmethod
    def get(tag: android.nfc.Tag, /) -> NfcB: ...
    def getApplicationData(self) -> java.chaquopy.JavaArrayJByte: ...
    def getMaxTransceiveLength(self) -> int: ...
    def getProtocolInfo(self) -> java.chaquopy.JavaArrayJByte: ...
    def getTag(self) -> android.nfc.Tag: ...
    def isConnected(self) -> bool: ...
    def transceive(self, data: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...

class NfcBarcode(TagTechnology):
    TYPE_KOVIO: typing.ClassVar[int] = ...
    TYPE_UNKNOWN: typing.ClassVar[int] = ...
    def close(self) -> None: ...
    def connect(self) -> None: ...
    @staticmethod
    def get(tag: android.nfc.Tag, /) -> NfcBarcode: ...
    def getBarcode(self) -> java.chaquopy.JavaArrayJByte: ...
    def getTag(self) -> android.nfc.Tag: ...
    def getType(self) -> int: ...
    def isConnected(self) -> bool: ...

class NfcF(TagTechnology):
    def close(self) -> None: ...
    def connect(self) -> None: ...
    @staticmethod
    def get(tag: android.nfc.Tag, /) -> NfcF: ...
    def getManufacturer(self) -> java.chaquopy.JavaArrayJByte: ...
    def getMaxTransceiveLength(self) -> int: ...
    def getSystemCode(self) -> java.chaquopy.JavaArrayJByte: ...
    def getTag(self) -> android.nfc.Tag: ...
    def getTimeout(self) -> int: ...
    def isConnected(self) -> bool: ...
    def setTimeout(self, timeout: int | java.jint | java.lang.Integer, /) -> None: ...
    def transceive(self, data: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...

class NfcV(TagTechnology):
    def close(self) -> None: ...
    def connect(self) -> None: ...
    @staticmethod
    def get(tag: android.nfc.Tag, /) -> NfcV: ...
    def getDsfId(self) -> int: ...
    def getMaxTransceiveLength(self) -> int: ...
    def getResponseFlags(self) -> int: ...
    def getTag(self) -> android.nfc.Tag: ...
    def isConnected(self) -> bool: ...
    def transceive(self, data: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...

class TagTechnology(java.io.Closeable):
    def close(self) -> None: ...
    def connect(self) -> None: ...
    def getTag(self) -> android.nfc.Tag: ...
    def isConnected(self) -> bool: ...



import typing

import android.adservices.common
import android.content
import android.os
import java
import java.lang
import java.util.concurrent

class AdId(java.lang.Object):
    ZERO_OUT: typing.ClassVar[str] = ...
    def __init__(self, adId: str | java.lang.String, limitAdTrackingEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdId(self) -> str: ...
    def hashCode(self) -> int: ...
    def isLimitAdTrackingEnabled(self) -> bool: ...
    def toString(self) -> str: ...

class AdIdManager(java.lang.Object):
    @staticmethod
    def get(context: android.content.Context, /) -> AdIdManager: ...
    @typing.overload
    def getAdId(self, executor: java.util.concurrent.Executor, callback: android.adservices.common.AdServicesOutcomeReceiver[AdId, java.lang.Exception], /) -> None: ...
    @typing.overload
    def getAdId(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[AdId, java.lang.Exception], /) -> None: ...



import typing

import android.os
import java
import java.lang
import java.util

class Light(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Light]] = ...
    LIGHT_CAPABILITY_BRIGHTNESS: typing.ClassVar[int] = ...
    LIGHT_CAPABILITY_COLOR_RGB: typing.ClassVar[int] = ...
    LIGHT_CAPABILITY_RGB: typing.ClassVar[int] = ...
    LIGHT_TYPE_INPUT: typing.ClassVar[int] = ...
    LIGHT_TYPE_KEYBOARD_BACKLIGHT: typing.ClassVar[int] = ...
    LIGHT_TYPE_MICROPHONE: typing.ClassVar[int] = ...
    LIGHT_TYPE_PLAYER_ID: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getId(self) -> int: ...
    def getName(self) -> str: ...
    def getOrdinal(self) -> int: ...
    def getType(self) -> int: ...
    def hasBrightnessControl(self) -> bool: ...
    def hasRgbControl(self) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class LightState(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[LightState]] = ...
    def describeContents(self) -> int: ...
    def getColor(self) -> int: ...
    def getPlayerId(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> LightState: ...
        def setColor(self, color: int | java.jint | java.lang.Integer, /) -> LightState.Builder: ...
        def setPlayerId(self, playerId: int | java.jint | java.lang.Integer, /) -> LightState.Builder: ...

class LightsManager(java.lang.Object):
    def getLightState(self, arg1: Light, /) -> LightState: ...
    def getLights(self) -> java.util.List[Light]: ...
    def openSession(self) -> LightsManager.LightsSession: ...

    class LightsSession(java.lang.AutoCloseable):
        def close(self) -> None: ...
        def requestLights(self, arg1: LightsRequest, /) -> None: ...

class LightsRequest(java.lang.Object):
    def getLightStates(self) -> java.util.List[LightState]: ...
    def getLights(self) -> java.util.List[java.lang.Integer]: ...
    def getLightsAndStates(self) -> java.util.Map[Light, LightState]: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addLight(self, light: Light, state: LightState, /) -> LightsRequest.Builder: ...
        def build(self) -> LightsRequest: ...
        def clearLight(self, light: Light, /) -> LightsRequest.Builder: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.util

class XmlPullParser(java.lang.Object):
    CDSECT: typing.ClassVar[int] = ...
    COMMENT: typing.ClassVar[int] = ...
    DOCDECL: typing.ClassVar[int] = ...
    END_DOCUMENT: typing.ClassVar[int] = ...
    END_TAG: typing.ClassVar[int] = ...
    ENTITY_REF: typing.ClassVar[int] = ...
    FEATURE_PROCESS_DOCDECL: typing.ClassVar[str] = ...
    FEATURE_PROCESS_NAMESPACES: typing.ClassVar[str] = ...
    FEATURE_REPORT_NAMESPACE_ATTRIBUTES: typing.ClassVar[str] = ...
    FEATURE_VALIDATION: typing.ClassVar[str] = ...
    IGNORABLE_WHITESPACE: typing.ClassVar[int] = ...
    NO_NAMESPACE: typing.ClassVar[str] = ...
    PROCESSING_INSTRUCTION: typing.ClassVar[int] = ...
    START_DOCUMENT: typing.ClassVar[int] = ...
    START_TAG: typing.ClassVar[int] = ...
    TEXT: typing.ClassVar[int] = ...
    TYPES: typing.ClassVar[java.chaquopy.JavaArray[java.lang.String]] = ...
    def defineEntityReplacementText(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
    def getAttributeCount(self) -> int: ...
    def getAttributeName(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    def getAttributeNamespace(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    def getAttributePrefix(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    def getAttributeType(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getAttributeValue(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getAttributeValue(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> str: ...
    def getColumnNumber(self) -> int: ...
    def getDepth(self) -> int: ...
    def getEventType(self) -> int: ...
    def getFeature(self, arg1: str | java.lang.String, /) -> bool: ...
    def getInputEncoding(self) -> str: ...
    def getLineNumber(self) -> int: ...
    def getName(self) -> str: ...
    @typing.overload
    def getNamespace(self) -> str: ...
    @typing.overload
    def getNamespace(self, arg1: str | java.lang.String, /) -> str: ...
    def getNamespaceCount(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getNamespacePrefix(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    def getNamespaceUri(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    def getPositionDescription(self) -> str: ...
    def getPrefix(self) -> str: ...
    def getProperty(self, arg1: str | java.lang.String, /) -> java.lang.Object: ...
    def getText(self) -> str: ...
    def getTextCharacters(self, arg1: java.chaquopy.JavaArrayJInt, /) -> java.chaquopy.JavaArrayJChar: ...
    def isAttributeDefault(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isEmptyElementTag(self) -> bool: ...
    def isWhitespace(self) -> bool: ...
    def next(self) -> int: ...
    def nextTag(self) -> int: ...
    def nextText(self) -> str: ...
    def nextToken(self) -> int: ...
    def require(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, arg3: str | java.lang.String, /) -> None: ...
    def setFeature(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setInput(self, arg1: java.io.Reader, /) -> None: ...
    @typing.overload
    def setInput(self, arg1: java.io.InputStream, arg2: str | java.lang.String, /) -> None: ...
    def setProperty(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...

class XmlPullParserException(java.lang.Exception):
    column: int = ...
    detail: java.lang.Throwable = ...
    row: int = ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, parser: XmlPullParser, chain: java.lang.Throwable, /) -> None: ...
    def getColumnNumber(self) -> int: ...
    def getDetail(self) -> java.lang.Throwable: ...
    def getLineNumber(self) -> int: ...
    def printStackTrace(self) -> None: ...

class XmlPullParserFactory(java.lang.Object):
    PROPERTY_NAME: typing.ClassVar[str] = ...
    classNamesLocation: str = ...
    features: java.util.HashMap[java.lang.String, java.lang.Boolean] = ...
    parserClasses: java.util.ArrayList = ...
    serializerClasses: java.util.ArrayList = ...
    def __init__(self) -> None: ...
    def getFeature(self, name: str | java.lang.String, /) -> bool: ...
    def isNamespaceAware(self) -> bool: ...
    def isValidating(self) -> bool: ...
    @typing.overload
    @staticmethod
    def newInstance() -> XmlPullParserFactory: ...
    @typing.overload
    @staticmethod
    def newInstance(unused: str | java.lang.String, unused2: typing.Type, /) -> XmlPullParserFactory: ...
    def newPullParser(self) -> XmlPullParser: ...
    def newSerializer(self) -> XmlSerializer: ...
    def setFeature(self, name: str | java.lang.String, state: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setNamespaceAware(self, awareness: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setValidating(self, validating: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class XmlSerializer(java.lang.Object):
    def attribute(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: str | java.lang.String, /) -> XmlSerializer: ...
    def cdsect(self, arg1: str | java.lang.String, /) -> None: ...
    def comment(self, arg1: str | java.lang.String, /) -> None: ...
    def docdecl(self, arg1: str | java.lang.String, /) -> None: ...
    def endDocument(self) -> None: ...
    def endTag(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> XmlSerializer: ...
    def entityRef(self, arg1: str | java.lang.String, /) -> None: ...
    def flush(self) -> None: ...
    def getDepth(self) -> int: ...
    def getFeature(self, arg1: str | java.lang.String, /) -> bool: ...
    def getName(self) -> str: ...
    def getNamespace(self) -> str: ...
    def getPrefix(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> str: ...
    def getProperty(self, arg1: str | java.lang.String, /) -> java.lang.Object: ...
    def ignorableWhitespace(self, arg1: str | java.lang.String, /) -> None: ...
    def processingInstruction(self, arg1: str | java.lang.String, /) -> None: ...
    def setFeature(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setOutput(self, arg1: java.io.Writer, /) -> None: ...
    @typing.overload
    def setOutput(self, arg1: java.io.OutputStream, arg2: str | java.lang.String, /) -> None: ...
    def setPrefix(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
    def setProperty(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...
    def startDocument(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def startTag(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> XmlSerializer: ...
    @typing.overload
    def text(self, arg1: str | java.lang.String, /) -> XmlSerializer: ...
    @typing.overload
    def text(self, arg1: java.chaquopy.JavaArrayJChar, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> XmlSerializer: ...



import typing

import java
import java.lang

class Attr(Node):
    def getName(self) -> str: ...
    def getOwnerElement(self) -> Element: ...
    def getSchemaTypeInfo(self) -> TypeInfo: ...
    def getSpecified(self) -> bool: ...
    def getValue(self) -> str: ...
    def isId(self) -> bool: ...
    def setValue(self, arg1: str | java.lang.String, /) -> None: ...

class CDATASection(Text): ...

class CharacterData(Node):
    def appendData(self, arg1: str | java.lang.String, /) -> None: ...
    def deleteData(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def getData(self) -> str: ...
    def getLength(self) -> int: ...
    def insertData(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> None: ...
    def replaceData(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: str | java.lang.String, /) -> None: ...
    def setData(self, arg1: str | java.lang.String, /) -> None: ...
    def substringData(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> str: ...

class Comment(CharacterData): ...

class DOMConfiguration(java.lang.Object):
    def canSetParameter(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getParameter(self, arg1: str | java.lang.String, /) -> java.lang.Object: ...
    def getParameterNames(self) -> DOMStringList: ...
    def setParameter(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...

class DOMError(java.lang.Object):
    SEVERITY_ERROR: typing.ClassVar[int] = ...
    SEVERITY_FATAL_ERROR: typing.ClassVar[int] = ...
    SEVERITY_WARNING: typing.ClassVar[int] = ...
    def getLocation(self) -> DOMLocator: ...
    def getMessage(self) -> str: ...
    def getRelatedData(self) -> java.lang.Object: ...
    def getRelatedException(self) -> java.lang.Object: ...
    def getSeverity(self) -> int: ...
    def getType(self) -> str: ...

class DOMErrorHandler(java.lang.Object):
    def handleError(self, arg1: DOMError, /) -> bool: ...

class DOMException(java.lang.RuntimeException):
    DOMSTRING_SIZE_ERR: typing.ClassVar[int] = ...
    HIERARCHY_REQUEST_ERR: typing.ClassVar[int] = ...
    INDEX_SIZE_ERR: typing.ClassVar[int] = ...
    INUSE_ATTRIBUTE_ERR: typing.ClassVar[int] = ...
    INVALID_ACCESS_ERR: typing.ClassVar[int] = ...
    INVALID_CHARACTER_ERR: typing.ClassVar[int] = ...
    INVALID_MODIFICATION_ERR: typing.ClassVar[int] = ...
    INVALID_STATE_ERR: typing.ClassVar[int] = ...
    NAMESPACE_ERR: typing.ClassVar[int] = ...
    NOT_FOUND_ERR: typing.ClassVar[int] = ...
    NOT_SUPPORTED_ERR: typing.ClassVar[int] = ...
    NO_DATA_ALLOWED_ERR: typing.ClassVar[int] = ...
    NO_MODIFICATION_ALLOWED_ERR: typing.ClassVar[int] = ...
    SYNTAX_ERR: typing.ClassVar[int] = ...
    TYPE_MISMATCH_ERR: typing.ClassVar[int] = ...
    VALIDATION_ERR: typing.ClassVar[int] = ...
    WRONG_DOCUMENT_ERR: typing.ClassVar[int] = ...
    code: int = ...
    def __init__(self, code: int | java.jshort | java.lang.Short, message: str | java.lang.String, /) -> None: ...

class DOMImplementation(java.lang.Object):
    def createDocument(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: DocumentType, /) -> Document: ...
    def createDocumentType(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: str | java.lang.String, /) -> DocumentType: ...
    def getFeature(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> java.lang.Object: ...
    def hasFeature(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> bool: ...

class DOMImplementationList(java.lang.Object):
    def getLength(self) -> int: ...
    def item(self, arg1: int | java.jint | java.lang.Integer, /) -> DOMImplementation: ...

class DOMImplementationSource(java.lang.Object):
    def getDOMImplementation(self, arg1: str | java.lang.String, /) -> DOMImplementation: ...
    def getDOMImplementationList(self, arg1: str | java.lang.String, /) -> DOMImplementationList: ...

class DOMLocator(java.lang.Object):
    def getByteOffset(self) -> int: ...
    def getColumnNumber(self) -> int: ...
    def getLineNumber(self) -> int: ...
    def getRelatedNode(self) -> Node: ...
    def getUri(self) -> str: ...
    def getUtf16Offset(self) -> int: ...

class DOMStringList(java.lang.Object):
    def contains(self, arg1: str | java.lang.String, /) -> bool: ...
    def getLength(self) -> int: ...
    def item(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...

class Document(Node):
    def adoptNode(self, arg1: Node, /) -> Node: ...
    def createAttribute(self, arg1: str | java.lang.String, /) -> Attr: ...
    def createAttributeNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> Attr: ...
    def createCDATASection(self, arg1: str | java.lang.String, /) -> CDATASection: ...
    def createComment(self, arg1: str | java.lang.String, /) -> Comment: ...
    def createDocumentFragment(self) -> DocumentFragment: ...
    def createElement(self, arg1: str | java.lang.String, /) -> Element: ...
    def createElementNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> Element: ...
    def createEntityReference(self, arg1: str | java.lang.String, /) -> EntityReference: ...
    def createProcessingInstruction(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> ProcessingInstruction: ...
    def createTextNode(self, arg1: str | java.lang.String, /) -> Text: ...
    def getDoctype(self) -> DocumentType: ...
    def getDocumentElement(self) -> Element: ...
    def getDocumentURI(self) -> str: ...
    def getDomConfig(self) -> DOMConfiguration: ...
    def getElementById(self, arg1: str | java.lang.String, /) -> Element: ...
    def getElementsByTagName(self, arg1: str | java.lang.String, /) -> NodeList: ...
    def getElementsByTagNameNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> NodeList: ...
    def getImplementation(self) -> DOMImplementation: ...
    def getInputEncoding(self) -> str: ...
    def getStrictErrorChecking(self) -> bool: ...
    def getXmlEncoding(self) -> str: ...
    def getXmlStandalone(self) -> bool: ...
    def getXmlVersion(self) -> str: ...
    def importNode(self, arg1: Node, arg2: bool | java.jboolean | java.lang.Boolean, /) -> Node: ...
    def normalizeDocument(self) -> None: ...
    def renameNode(self, arg1: Node, arg2: str | java.lang.String, arg3: str | java.lang.String, /) -> Node: ...
    def setDocumentURI(self, arg1: str | java.lang.String, /) -> None: ...
    def setStrictErrorChecking(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setXmlStandalone(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setXmlVersion(self, arg1: str | java.lang.String, /) -> None: ...

class DocumentFragment(Node): ...

class DocumentType(Node):
    def getEntities(self) -> NamedNodeMap: ...
    def getInternalSubset(self) -> str: ...
    def getName(self) -> str: ...
    def getNotations(self) -> NamedNodeMap: ...
    def getPublicId(self) -> str: ...
    def getSystemId(self) -> str: ...

class Element(Node):
    def getAttribute(self, arg1: str | java.lang.String, /) -> str: ...
    def getAttributeNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> str: ...
    def getAttributeNode(self, arg1: str | java.lang.String, /) -> Attr: ...
    def getAttributeNodeNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> Attr: ...
    def getElementsByTagName(self, arg1: str | java.lang.String, /) -> NodeList: ...
    def getElementsByTagNameNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> NodeList: ...
    def getSchemaTypeInfo(self) -> TypeInfo: ...
    def getTagName(self) -> str: ...
    def hasAttribute(self, arg1: str | java.lang.String, /) -> bool: ...
    def hasAttributeNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> bool: ...
    def removeAttribute(self, arg1: str | java.lang.String, /) -> None: ...
    def removeAttributeNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
    def removeAttributeNode(self, arg1: Attr, /) -> Attr: ...
    def setAttribute(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
    def setAttributeNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: str | java.lang.String, /) -> None: ...
    def setAttributeNode(self, arg1: Attr, /) -> Attr: ...
    def setAttributeNodeNS(self, arg1: Attr, /) -> Attr: ...
    def setIdAttribute(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setIdAttributeNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setIdAttributeNode(self, arg1: Attr, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class Entity(Node):
    def getInputEncoding(self) -> str: ...
    def getNotationName(self) -> str: ...
    def getPublicId(self) -> str: ...
    def getSystemId(self) -> str: ...
    def getXmlEncoding(self) -> str: ...
    def getXmlVersion(self) -> str: ...

class EntityReference(Node): ...

class NameList(java.lang.Object):
    def contains(self, arg1: str | java.lang.String, /) -> bool: ...
    def containsNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> bool: ...
    def getLength(self) -> int: ...
    def getName(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    def getNamespaceURI(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...

class NamedNodeMap(java.lang.Object):
    def getLength(self) -> int: ...
    def getNamedItem(self, arg1: str | java.lang.String, /) -> Node: ...
    def getNamedItemNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> Node: ...
    def item(self, arg1: int | java.jint | java.lang.Integer, /) -> Node: ...
    def removeNamedItem(self, arg1: str | java.lang.String, /) -> Node: ...
    def removeNamedItemNS(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> Node: ...
    def setNamedItem(self, arg1: Node, /) -> Node: ...
    def setNamedItemNS(self, arg1: Node, /) -> Node: ...

class Node(java.lang.Object):
    ATTRIBUTE_NODE: typing.ClassVar[int] = ...
    CDATA_SECTION_NODE: typing.ClassVar[int] = ...
    COMMENT_NODE: typing.ClassVar[int] = ...
    DOCUMENT_FRAGMENT_NODE: typing.ClassVar[int] = ...
    DOCUMENT_NODE: typing.ClassVar[int] = ...
    DOCUMENT_POSITION_CONTAINED_BY: typing.ClassVar[int] = ...
    DOCUMENT_POSITION_CONTAINS: typing.ClassVar[int] = ...
    DOCUMENT_POSITION_DISCONNECTED: typing.ClassVar[int] = ...
    DOCUMENT_POSITION_FOLLOWING: typing.ClassVar[int] = ...
    DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: typing.ClassVar[int] = ...
    DOCUMENT_POSITION_PRECEDING: typing.ClassVar[int] = ...
    DOCUMENT_TYPE_NODE: typing.ClassVar[int] = ...
    ELEMENT_NODE: typing.ClassVar[int] = ...
    ENTITY_NODE: typing.ClassVar[int] = ...
    ENTITY_REFERENCE_NODE: typing.ClassVar[int] = ...
    NOTATION_NODE: typing.ClassVar[int] = ...
    PROCESSING_INSTRUCTION_NODE: typing.ClassVar[int] = ...
    TEXT_NODE: typing.ClassVar[int] = ...
    def appendChild(self, arg1: Node, /) -> Node: ...
    def cloneNode(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> Node: ...
    def compareDocumentPosition(self, arg1: Node, /) -> int: ...
    def getAttributes(self) -> NamedNodeMap: ...
    def getBaseURI(self) -> str: ...
    def getChildNodes(self) -> NodeList: ...
    def getFeature(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> java.lang.Object: ...
    def getFirstChild(self) -> Node: ...
    def getLastChild(self) -> Node: ...
    def getLocalName(self) -> str: ...
    def getNamespaceURI(self) -> str: ...
    def getNextSibling(self) -> Node: ...
    def getNodeName(self) -> str: ...
    def getNodeType(self) -> int: ...
    def getNodeValue(self) -> str: ...
    def getOwnerDocument(self) -> Document: ...
    def getParentNode(self) -> Node: ...
    def getPrefix(self) -> str: ...
    def getPreviousSibling(self) -> Node: ...
    def getTextContent(self) -> str: ...
    def getUserData(self, arg1: str | java.lang.String, /) -> java.lang.Object: ...
    def hasAttributes(self) -> bool: ...
    def hasChildNodes(self) -> bool: ...
    def insertBefore(self, arg1: Node, arg2: Node, /) -> Node: ...
    def isDefaultNamespace(self, arg1: str | java.lang.String, /) -> bool: ...
    def isEqualNode(self, arg1: Node, /) -> bool: ...
    def isSameNode(self, arg1: Node, /) -> bool: ...
    def isSupported(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> bool: ...
    def lookupNamespaceURI(self, arg1: str | java.lang.String, /) -> str: ...
    def lookupPrefix(self, arg1: str | java.lang.String, /) -> str: ...
    def normalize(self) -> None: ...
    def removeChild(self, arg1: Node, /) -> Node: ...
    def replaceChild(self, arg1: Node, arg2: Node, /) -> Node: ...
    def setNodeValue(self, arg1: str | java.lang.String, /) -> None: ...
    def setPrefix(self, arg1: str | java.lang.String, /) -> None: ...
    def setTextContent(self, arg1: str | java.lang.String, /) -> None: ...
    def setUserData(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, arg3: UserDataHandler, /) -> java.lang.Object: ...

class NodeList(java.lang.Object):
    def getLength(self) -> int: ...
    def item(self, arg1: int | java.jint | java.lang.Integer, /) -> Node: ...

class Notation(Node):
    def getPublicId(self) -> str: ...
    def getSystemId(self) -> str: ...

class ProcessingInstruction(Node):
    def getData(self) -> str: ...
    def getTarget(self) -> str: ...
    def setData(self, arg1: str | java.lang.String, /) -> None: ...

class Text(CharacterData):
    def getWholeText(self) -> str: ...
    def isElementContentWhitespace(self) -> bool: ...
    def replaceWholeText(self, arg1: str | java.lang.String, /) -> Text: ...
    def splitText(self, arg1: int | java.jint | java.lang.Integer, /) -> Text: ...

class TypeInfo(java.lang.Object):
    DERIVATION_EXTENSION: typing.ClassVar[int] = ...
    DERIVATION_LIST: typing.ClassVar[int] = ...
    DERIVATION_RESTRICTION: typing.ClassVar[int] = ...
    DERIVATION_UNION: typing.ClassVar[int] = ...
    def getTypeName(self) -> str: ...
    def getTypeNamespace(self) -> str: ...
    def isDerivedFrom(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...

class UserDataHandler(java.lang.Object):
    NODE_ADOPTED: typing.ClassVar[int] = ...
    NODE_CLONED: typing.ClassVar[int] = ...
    NODE_DELETED: typing.ClassVar[int] = ...
    NODE_IMPORTED: typing.ClassVar[int] = ...
    NODE_RENAMED: typing.ClassVar[int] = ...
    def handle(self, arg1: int | java.jshort | java.lang.Short, arg2: str | java.lang.String, arg3: java.lang.Object | int | bool | float | str, arg4: Node, arg5: Node, /) -> None: ...



import typing

import android.content
import android.graphics
import android.os
import android.view
import android.view.autofill
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class ContentCaptureCondition(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ContentCaptureCondition]] = ...
    FLAG_IS_REGEX: typing.ClassVar[int] = ...
    def __init__(self, locusId: android.content.LocusId, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFlags(self) -> int: ...
    def getLocusId(self) -> android.content.LocusId: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ContentCaptureContext(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ContentCaptureContext]] = ...
    def describeContents(self) -> int: ...
    @staticmethod
    def forLocusId(id: str | java.lang.String, /) -> ContentCaptureContext: ...
    def getExtras(self) -> android.os.Bundle | None: ...
    def getLocusId(self) -> android.content.LocusId | None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, id: android.content.LocusId, /) -> None: ...
        def build(self) -> ContentCaptureContext: ...
        def setExtras(self, extras: android.os.Bundle, /) -> ContentCaptureContext.Builder: ...

class ContentCaptureManager(java.lang.Object):
    DATA_SHARE_ERROR_CONCURRENT_REQUEST: typing.ClassVar[int] = ...
    DATA_SHARE_ERROR_TIMEOUT_INTERRUPTED: typing.ClassVar[int] = ...
    DATA_SHARE_ERROR_UNKNOWN: typing.ClassVar[int] = ...
    def getContentCaptureConditions(self) -> java.util.Set[ContentCaptureCondition] | None: ...
    def getServiceComponentName(self) -> android.content.ComponentName | None: ...
    def isContentCaptureEnabled(self) -> bool: ...
    def removeData(self, request: DataRemovalRequest, /) -> None: ...
    def setContentCaptureEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def shareData(self, request: DataShareRequest, executor: java.util.concurrent.Executor, dataShareWriteAdapter: DataShareWriteAdapter, /) -> None: ...

class ContentCaptureSession(java.lang.AutoCloseable):
    def close(self) -> None: ...
    def createContentCaptureSession(self, context: ContentCaptureContext, /) -> ContentCaptureSession: ...
    def destroy(self) -> None: ...
    def flush(self) -> None: ...
    def getContentCaptureContext(self) -> ContentCaptureContext | None: ...
    def getContentCaptureSessionId(self) -> ContentCaptureSessionId: ...
    def newAutofillId(self, hostId: android.view.autofill.AutofillId, virtualChildId: int | java.jlong | java.lang.Long, /) -> android.view.autofill.AutofillId: ...
    def newViewStructure(self, view: android.view.View, /) -> android.view.ViewStructure: ...
    def newVirtualViewStructure(self, parentId: android.view.autofill.AutofillId, virtualId: int | java.jlong | java.lang.Long, /) -> android.view.ViewStructure: ...
    def notifySessionPaused(self) -> None: ...
    def notifySessionResumed(self) -> None: ...
    def notifyViewAppeared(self, node: android.view.ViewStructure, /) -> None: ...
    def notifyViewDisappeared(self, id: android.view.autofill.AutofillId, /) -> None: ...
    def notifyViewInsetsChanged(self, viewInsets: android.graphics.Insets, /) -> None: ...
    def notifyViewTextChanged(self, id: android.view.autofill.AutofillId, text: java.lang.CharSequence, /) -> None: ...
    def notifyViewsAppeared(self, appearedNodes: java.util.List[android.view.ViewStructure], /) -> None: ...
    def notifyViewsDisappeared(self, hostId: android.view.autofill.AutofillId, virtualIds: java.chaquopy.JavaArrayJLong, /) -> None: ...
    def setContentCaptureContext(self, context: ContentCaptureContext, /) -> None: ...
    def toString(self) -> str: ...

class ContentCaptureSessionId(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ContentCaptureSessionId]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DataRemovalRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DataRemovalRequest]] = ...
    FLAG_IS_PREFIX: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getLocusIdRequests(self) -> java.util.List[DataRemovalRequest.LocusIdRequest]: ...
    def getPackageName(self) -> str: ...
    def isForEverything(self) -> bool: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class LocusIdRequest(java.lang.Object):
        def getFlags(self) -> int: ...
        def getLocusId(self) -> android.content.LocusId: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addLocusId(self, locusId: android.content.LocusId, flags: int | java.jint | java.lang.Integer, /) -> DataRemovalRequest.Builder: ...
        def build(self) -> DataRemovalRequest: ...
        def forEverything(self) -> DataRemovalRequest.Builder: ...

class DataShareRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DataShareRequest]] = ...
    def __init__(self, locusId: android.content.LocusId, mimeType: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getLocusId(self) -> android.content.LocusId | None: ...
    def getMimeType(self) -> str: ...
    def getPackageName(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DataShareWriteAdapter(java.lang.Object):
    def onError(self, errorCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRejected(self) -> None: ...
    def onWrite(self, arg1: android.os.ParcelFileDescriptor, /) -> None: ...



import typing

import android.net
import android.os
import java
import java.chaquopy
import java.lang
import java.net
import java.util
import java.util.concurrent
import java.util.function

class AttachCallback(java.lang.Object):
    def __init__(self) -> None: ...
    def onAttachFailed(self) -> None: ...
    def onAttached(self, session: WifiAwareSession, /) -> None: ...
    def onAwareSessionTerminated(self) -> None: ...

class AwarePairingConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AwarePairingConfig]] = ...
    PAIRING_BOOTSTRAPPING_NFC_READER: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_NFC_TAG: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_OPPORTUNISTIC: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_PASSPHRASE_DISPLAY: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_PASSPHRASE_KEYPAD: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_PIN_CODE_DISPLAY: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_PIN_CODE_KEYPAD: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_QR_DISPLAY: typing.ClassVar[int] = ...
    PAIRING_BOOTSTRAPPING_QR_SCAN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBootstrappingMethods(self) -> int: ...
    def getSupportedCipherSuites(self) -> int: ...
    def hashCode(self) -> int: ...
    def isPairingCacheEnabled(self) -> bool: ...
    def isPairingSetupEnabled(self) -> bool: ...
    def isPairingVerificationEnabled(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> AwarePairingConfig: ...
        def setBootstrappingMethods(self, methods: int | java.jint | java.lang.Integer, /) -> AwarePairingConfig.Builder: ...
        def setPairingCacheEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> AwarePairingConfig.Builder: ...
        def setPairingSetupEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> AwarePairingConfig.Builder: ...
        def setPairingVerificationEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> AwarePairingConfig.Builder: ...
        def setSupportedCipherSuites(self, cipherSuites: int | java.jint | java.lang.Integer, /) -> AwarePairingConfig.Builder: ...

class AwareResources(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AwareResources]] = ...
    def __init__(self, availableDataPathsCount: int | java.jint | java.lang.Integer, availablePublishSessionsCount: int | java.jint | java.lang.Integer, availableSubscribeSessionsCount: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getAvailableDataPathsCount(self) -> int: ...
    def getAvailablePublishSessionsCount(self) -> int: ...
    def getAvailableSubscribeSessionsCount(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Characteristics(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Characteristics]] = ...
    WIFI_AWARE_CIPHER_SUITE_NCS_PK_128: typing.ClassVar[int] = ...
    WIFI_AWARE_CIPHER_SUITE_NCS_PK_256: typing.ClassVar[int] = ...
    WIFI_AWARE_CIPHER_SUITE_NCS_PK_PASN_128: typing.ClassVar[int] = ...
    WIFI_AWARE_CIPHER_SUITE_NCS_PK_PASN_256: typing.ClassVar[int] = ...
    WIFI_AWARE_CIPHER_SUITE_NCS_SK_128: typing.ClassVar[int] = ...
    WIFI_AWARE_CIPHER_SUITE_NCS_SK_256: typing.ClassVar[int] = ...
    WIFI_AWARE_CIPHER_SUITE_NONE: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getMaxMatchFilterLength(self) -> int: ...
    def getMaxServiceNameLength(self) -> int: ...
    def getMaxServiceSpecificInfoLength(self) -> int: ...
    def getNumberOfSupportedDataInterfaces(self) -> int: ...
    def getNumberOfSupportedDataPaths(self) -> int: ...
    def getNumberOfSupportedPublishSessions(self) -> int: ...
    def getNumberOfSupportedSubscribeSessions(self) -> int: ...
    def getSupportedCipherSuites(self) -> int: ...
    def getSupportedPairingCipherSuites(self) -> int: ...
    def isAwarePairingSupported(self) -> bool: ...
    def isInstantCommunicationModeSupported(self) -> bool: ...
    def isSuspensionSupported(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DiscoverySession(java.lang.AutoCloseable):
    def acceptPairingRequest(self, requestId: int | java.jint | java.lang.Integer, peerHandle: PeerHandle, peerDeviceAlias: str | java.lang.String, cipherSuite: int | java.jint | java.lang.Integer, password: str | java.lang.String, /) -> None: ...
    def close(self) -> None: ...
    def createNetworkSpecifierOpen(self, peerHandle: PeerHandle, /) -> android.net.NetworkSpecifier: ...
    def createNetworkSpecifierPassphrase(self, peerHandle: PeerHandle, passphrase: str | java.lang.String, /) -> android.net.NetworkSpecifier: ...
    def finalize(self) -> None: ...
    def initiateBootstrappingRequest(self, peerHandle: PeerHandle, method: int | java.jint | java.lang.Integer, /) -> None: ...
    def initiatePairingRequest(self, peerHandle: PeerHandle, peerDeviceAlias: str | java.lang.String, cipherSuite: int | java.jint | java.lang.Integer, password: str | java.lang.String, /) -> None: ...
    def rejectPairingRequest(self, requestId: int | java.jint | java.lang.Integer, peerHandle: PeerHandle, /) -> None: ...
    def sendMessage(self, peerHandle: PeerHandle, messageId: int | java.jint | java.lang.Integer, message: java.chaquopy.JavaArrayJByte, /) -> None: ...

class DiscoverySessionCallback(java.lang.Object):
    def __init__(self) -> None: ...
    def onBootstrappingFailed(self, peerHandle: PeerHandle, /) -> None: ...
    def onBootstrappingSucceeded(self, peerHandle: PeerHandle, method: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMessageReceived(self, peerHandle: PeerHandle, message: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def onMessageSendFailed(self, messageId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMessageSendSucceeded(self, messageId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onPairingSetupFailed(self, peerHandle: PeerHandle, /) -> None: ...
    def onPairingSetupRequestReceived(self, peerHandle: PeerHandle, requestId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onPairingSetupSucceeded(self, peerHandle: PeerHandle, alias: str | java.lang.String, /) -> None: ...
    def onPairingVerificationFailed(self, peerHandle: PeerHandle, /) -> None: ...
    def onPairingVerificationSucceed(self, peerHandle: PeerHandle, alias: str | java.lang.String, /) -> None: ...
    def onPublishStarted(self, session: PublishDiscoverySession, /) -> None: ...
    @typing.overload
    def onServiceDiscovered(self, info: ServiceDiscoveryInfo, /) -> None: ...
    @typing.overload
    def onServiceDiscovered(self, peerHandle: PeerHandle, serviceSpecificInfo: java.chaquopy.JavaArrayJByte, matchFilter: java.util.List[java.chaquopy.JavaArrayJByte], /) -> None: ...
    @typing.overload
    def onServiceDiscoveredWithinRange(self, info: ServiceDiscoveryInfo, distanceMm: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def onServiceDiscoveredWithinRange(self, peerHandle: PeerHandle, serviceSpecificInfo: java.chaquopy.JavaArrayJByte, matchFilter: java.util.List[java.chaquopy.JavaArrayJByte], distanceMm: int | java.jint | java.lang.Integer, /) -> None: ...
    def onServiceLost(self, peerHandle: PeerHandle, reason: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSessionConfigFailed(self) -> None: ...
    def onSessionConfigUpdated(self) -> None: ...
    def onSessionTerminated(self) -> None: ...
    def onSubscribeStarted(self, session: SubscribeDiscoverySession, /) -> None: ...

class IdentityChangedListener(java.lang.Object):
    CLUSTER_CHANGE_EVENT_JOINED: typing.ClassVar[int] = ...
    CLUSTER_CHANGE_EVENT_STARTED: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def onClusterIdChanged(self, clusterEventType: int | java.jint | java.lang.Integer, clusterId: android.net.MacAddress, /) -> None: ...
    def onIdentityChanged(self, mac: java.chaquopy.JavaArrayJByte, /) -> None: ...

class ParcelablePeerHandle(PeerHandle, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ParcelablePeerHandle]] = ...
    def __init__(self, peerHandle: PeerHandle, /) -> None: ...
    def describeContents(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PeerHandle(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...

class PublishConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PublishConfig]] = ...
    PUBLISH_TYPE_SOLICITED: typing.ClassVar[int] = ...
    PUBLISH_TYPE_UNSOLICITED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getInstantCommunicationBand(self) -> int: ...
    def getPairingConfig(self) -> AwarePairingConfig | None: ...
    def getSecurityConfig(self) -> WifiAwareDataPathSecurityConfig | None: ...
    def hashCode(self) -> int: ...
    def isInstantCommunicationModeEnabled(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> PublishConfig: ...
        def setDataPathSecurityConfig(self, securityConfig: WifiAwareDataPathSecurityConfig, /) -> PublishConfig.Builder: ...
        def setInstantCommunicationModeEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, band: int | java.jint | java.lang.Integer, /) -> PublishConfig.Builder: ...
        def setMatchFilter(self, matchFilter: java.util.List[java.chaquopy.JavaArrayJByte], /) -> PublishConfig.Builder: ...
        def setPairingConfig(self, config: AwarePairingConfig, /) -> PublishConfig.Builder: ...
        def setPublishType(self, publishType: int | java.jint | java.lang.Integer, /) -> PublishConfig.Builder: ...
        def setRangingEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> PublishConfig.Builder: ...
        def setServiceName(self, serviceName: str | java.lang.String, /) -> PublishConfig.Builder: ...
        def setServiceSpecificInfo(self, serviceSpecificInfo: java.chaquopy.JavaArrayJByte, /) -> PublishConfig.Builder: ...
        def setTerminateNotificationEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> PublishConfig.Builder: ...
        def setTtlSec(self, ttlSec: int | java.jint | java.lang.Integer, /) -> PublishConfig.Builder: ...

class PublishDiscoverySession(DiscoverySession):
    def updatePublish(self, publishConfig: PublishConfig, /) -> None: ...

class ServiceDiscoveryInfo(java.lang.Object):
    def getMatchFilters(self) -> java.util.List[java.chaquopy.JavaArrayJByte]: ...
    def getPairedAlias(self) -> str | None: ...
    def getPairingConfig(self) -> AwarePairingConfig | None: ...
    def getPeerCipherSuite(self) -> int: ...
    def getPeerHandle(self) -> PeerHandle: ...
    def getScid(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getServiceSpecificInfo(self) -> java.chaquopy.JavaArrayJByte | None: ...

class SubscribeConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SubscribeConfig]] = ...
    SUBSCRIBE_TYPE_ACTIVE: typing.ClassVar[int] = ...
    SUBSCRIBE_TYPE_PASSIVE: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getInstantCommunicationBand(self) -> int: ...
    def getPairingConfig(self) -> AwarePairingConfig | None: ...
    def hashCode(self) -> int: ...
    def isInstantCommunicationModeEnabled(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> SubscribeConfig: ...
        def setInstantCommunicationModeEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, band: int | java.jint | java.lang.Integer, /) -> SubscribeConfig.Builder: ...
        def setMatchFilter(self, matchFilter: java.util.List[java.chaquopy.JavaArrayJByte], /) -> SubscribeConfig.Builder: ...
        def setMaxDistanceMm(self, maxDistanceMm: int | java.jint | java.lang.Integer, /) -> SubscribeConfig.Builder: ...
        def setMinDistanceMm(self, minDistanceMm: int | java.jint | java.lang.Integer, /) -> SubscribeConfig.Builder: ...
        def setPairingConfig(self, config: AwarePairingConfig, /) -> SubscribeConfig.Builder: ...
        def setServiceName(self, serviceName: str | java.lang.String, /) -> SubscribeConfig.Builder: ...
        def setServiceSpecificInfo(self, serviceSpecificInfo: java.chaquopy.JavaArrayJByte, /) -> SubscribeConfig.Builder: ...
        def setSubscribeType(self, subscribeType: int | java.jint | java.lang.Integer, /) -> SubscribeConfig.Builder: ...
        def setTerminateNotificationEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> SubscribeConfig.Builder: ...
        def setTtlSec(self, ttlSec: int | java.jint | java.lang.Integer, /) -> SubscribeConfig.Builder: ...

class SubscribeDiscoverySession(DiscoverySession):
    def updateSubscribe(self, subscribeConfig: SubscribeConfig, /) -> None: ...

class WifiAwareChannelInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiAwareChannelInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getChannelBandwidth(self) -> int: ...
    def getChannelFrequencyMhz(self) -> int: ...
    def getSpatialStreamCount(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WifiAwareDataPathSecurityConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiAwareDataPathSecurityConfig]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCipherSuite(self) -> int: ...
    def getPmk(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getPmkId(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getPskPassphrase(self) -> str | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, cipherSuite: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> WifiAwareDataPathSecurityConfig: ...
        def setPmk(self, pmk: java.chaquopy.JavaArrayJByte, /) -> WifiAwareDataPathSecurityConfig.Builder: ...
        def setPmkId(self, pmkId: java.chaquopy.JavaArrayJByte, /) -> WifiAwareDataPathSecurityConfig.Builder: ...
        def setPskPassphrase(self, pskPassphrase: str | java.lang.String, /) -> WifiAwareDataPathSecurityConfig.Builder: ...

class WifiAwareManager(java.lang.Object):
    ACTION_WIFI_AWARE_RESOURCE_CHANGED: typing.ClassVar[str] = ...
    ACTION_WIFI_AWARE_STATE_CHANGED: typing.ClassVar[str] = ...
    EXTRA_AWARE_RESOURCES: typing.ClassVar[str] = ...
    WIFI_AWARE_DATA_PATH_ROLE_INITIATOR: typing.ClassVar[int] = ...
    WIFI_AWARE_DATA_PATH_ROLE_RESPONDER: typing.ClassVar[int] = ...
    WIFI_AWARE_DISCOVERY_LOST_REASON_PEER_NOT_VISIBLE: typing.ClassVar[int] = ...
    WIFI_AWARE_DISCOVERY_LOST_REASON_UNKNOWN: typing.ClassVar[int] = ...
    @typing.overload
    def attach(self, attachCallback: AttachCallback, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def attach(self, attachCallback: AttachCallback, identityChangedListener: IdentityChangedListener, handler: android.os.Handler, /) -> None: ...
    def getAvailableAwareResources(self) -> AwareResources | None: ...
    def getCharacteristics(self) -> Characteristics | None: ...
    def getPairedDevices(self, executor: java.util.concurrent.Executor, resultsCallback: java.util.function.Consumer[java.util.List[java.lang.String]], /) -> None: ...
    def isAvailable(self) -> bool: ...
    def isDeviceAttached(self) -> bool: ...
    def isInstantCommunicationModeEnabled(self) -> bool: ...
    def isOpportunisticModeEnabled(self, executor: java.util.concurrent.Executor, resultsCallback: java.util.function.Consumer[java.lang.Boolean], /) -> None: ...
    def isSetChannelOnDataPathSupported(self) -> bool: ...
    def removePairedDevice(self, alias: str | java.lang.String, /) -> None: ...
    def resetPairedDevices(self) -> None: ...
    def setOpportunisticModeEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class WifiAwareNetworkInfo(android.net.TransportInfo, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiAwareNetworkInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getChannelInfoList(self) -> java.util.List[WifiAwareChannelInfo]: ...
    def getPeerIpv6Addr(self) -> java.net.Inet6Address | None: ...
    def getPort(self) -> int: ...
    def getTransportProtocol(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WifiAwareNetworkSpecifier(android.net.NetworkSpecifier, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiAwareNetworkSpecifier]] = ...
    def canBeSatisfiedBy(self, other: android.net.NetworkSpecifier, /) -> bool: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getChannelFrequencyMhz(self) -> int: ...
    def getWifiAwareDataPathSecurityConfig(self) -> WifiAwareDataPathSecurityConfig | None: ...
    def hashCode(self) -> int: ...
    def isChannelRequired(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, publishDiscoverySession: PublishDiscoverySession, /) -> None: ...
        @typing.overload
        def __init__(self, discoverySession: DiscoverySession, peerHandle: PeerHandle, /) -> None: ...
        def build(self) -> WifiAwareNetworkSpecifier: ...
        def setChannelFrequencyMhz(self, channelInMhz: int | java.jint | java.lang.Integer, required: bool | java.jboolean | java.lang.Boolean, /) -> WifiAwareNetworkSpecifier.Builder: ...
        def setDataPathSecurityConfig(self, securityConfig: WifiAwareDataPathSecurityConfig, /) -> WifiAwareNetworkSpecifier.Builder: ...
        def setPmk(self, pmk: java.chaquopy.JavaArrayJByte, /) -> WifiAwareNetworkSpecifier.Builder: ...
        def setPort(self, port: int | java.jint | java.lang.Integer, /) -> WifiAwareNetworkSpecifier.Builder: ...
        def setPskPassphrase(self, pskPassphrase: str | java.lang.String, /) -> WifiAwareNetworkSpecifier.Builder: ...
        def setTransportProtocol(self, transportProtocol: int | java.jint | java.lang.Integer, /) -> WifiAwareNetworkSpecifier.Builder: ...

class WifiAwareSession(java.lang.AutoCloseable):
    def close(self) -> None: ...
    def createNetworkSpecifierOpen(self, role: int | java.jint | java.lang.Integer, peer: java.chaquopy.JavaArrayJByte, /) -> android.net.NetworkSpecifier: ...
    def createNetworkSpecifierPassphrase(self, role: int | java.jint | java.lang.Integer, peer: java.chaquopy.JavaArrayJByte, passphrase: str | java.lang.String, /) -> android.net.NetworkSpecifier: ...
    def finalize(self) -> None: ...
    def publish(self, publishConfig: PublishConfig, callback: DiscoverySessionCallback, handler: android.os.Handler, /) -> None: ...
    def subscribe(self, subscribeConfig: SubscribeConfig, callback: DiscoverySessionCallback, handler: android.os.Handler, /) -> None: ...
